@@ -39,6 +39,7 @@ nlp = spacy.load(en_core_web_sm)
 
 class RecipeReader:
     def __init__(self):
+        self._attributes = ["quantity", "unit", "size", "color", "ingredient", "simple"]
         pass
 
     def normalize(self, phrase):
@@ -85,7 +86,7 @@ class RecipeReader:
         return out
 
     def read_phrase(self, phrase):
-        if not P_filter(phrase):
+        if not P_filter(str(phrase)):
             return None
 
         phrase = html.unescape(phrase)
@@ -126,10 +127,9 @@ class RecipeReader:
                 values["quantity"], values["unit"]
             )
 
-        filtered = {
-            c: values[c]
-            for c in ["quantity", "unit", "size", "color", "ingredient", "simple"]
-        }
+        values["simple"] = re.sub(r"\bnan\b", "naan", values["simple"])
+
+        filtered = {c: values[c] for c in self._attributes}
         filtered["simple"] = values["simple"]
         return filtered
 
@@ -139,7 +139,6 @@ class RecipeReader:
     def clean_title(self, title):
         title = squish_multi_bracket(title)
         title = rm_nested_bracket(title)
-        # title = get_bracket_content(title)
         title = rm_bracket_content(title)
         title = rm_roman_numerals(title)
         title = re.sub(r" \|.+$", "", title)
@@ -152,13 +151,23 @@ class RecipeReader:
         title = re.sub(r"\bnan\b", r"\bnaan\b", title)
         return title
 
+    def alt_title(self, title):
+        title = squish_multi_bracket(title)
+        title = (
+            re.search(r"(?:\((?P<alt_title>.*)\))?$", title)
+            .groupdict()
+            .get("alt_title", "")
+        ) or ""
+        return title.lower()
+
     def categorize(self, title, ingredients, steps, parsedPhrases):
         categories = []
-        roots = [
-            token.text.lower()
-            for token in nlp(self.clean_title(title))
-            if token.dep_ == "ROOT"
+        alt_title = self.alt_title(title)
+        title = self.clean_title(title)
+        roots = [token.text.lower() for token in nlp(title) if token.dep_ == "ROOT"] + [
+            token.text.lower() for token in nlp(alt_title) if token.dep_ == "ROOT"
         ]
+
         if any(re.search(to_regex(exceptions), root) for root in roots):
             return ["niche"]
 
@@ -188,7 +197,7 @@ class RecipeReader:
                 categories.append(key)
 
         for key, regex in title_map.items():
-            if re.search(regex, title):
+            if re.search(regex, title) or re.search(regex, alt_title):
                 categories.append(key)
 
         for key, labelF in function_map.items():
@@ -198,6 +207,9 @@ class RecipeReader:
         if any(p in categories for p in proteins):
             categories = [c for c in categories if c != "vegetarian"]
 
+        if not len(categories):
+            categories = ["vegetarian"]
+
         return list(set(categories))
 
     def categories_to_models(self, categories_a):
@@ -244,7 +256,13 @@ TAG_EMBEDDING_LEN = 384
 
 
 class TagReader:
-    def __init__(self, ing_model):
+    def __init__(
+        self,
+        ing_model,
+        qdrant_host="qdrant.pocketsomm.dev",
+        qdrant_port=443,
+        qdrant_https=True,
+    ):
         tag_model_path = os.path.join(ROOT_DIR, "models", "tag_embedding.model")
         self.tag_model = SentenceTransformer(tag_model_path)
         self.ing_model = ing_model
@@ -256,7 +274,9 @@ class TagReader:
         self.tags = list(self.__mean_ing_e_per_tag.columns)
         self.__mean_ing_e = np.array(mean_ing_embedding)
 
-        self.qdrant = QdrantClient(host="qdrant.pocketsomm.dev", port=443, https=True)
+        self.qdrant = QdrantClient(
+            host=qdrant_host, port=qdrant_port, https=qdrant_https
+        )
 
     def generate_ing_embedding(self, ing):
         return self.ing_model.wv[ing] if ing in self.ing_model.wv else None
